@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2018 Synchrotron SOLEIL
+ * Copyright (C) 2003-2019, 2022 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -410,7 +410,7 @@ int hkl_mode_set_hkl_real(HklMode *self,
 
 		/* we will add solution to the geometries so save its length before */
 		for(i=0, item=list_top(&engine->engines->geometries->items, HklGeometryListItem, list);
-		    i<len;
+		    i<len && NULL != item;
 		    ++i, item=list_next(&engine->engines->geometries->items, item, list)){
 			int j;
 			HklVector ki;
@@ -806,7 +806,7 @@ HklMode *hkl_mode_hkl_emergence_fixed_new(const HklModeAutoInfo *auto_info)
 		exit(128);
 	}
 
-	self = HKL_MALLOC(HklModeAutoHklEmergenceFixed);
+	self = g_new(HklModeAutoHklEmergenceFixed, 1);
 
 	/* the base constructor; */
 	hkl_mode_auto_init(&self->parent,
@@ -834,7 +834,7 @@ static void hkl_engine_hkl_free_real(HklEngine *base)
 
 HklEngine *hkl_engine_hkl_new(HklEngineList *engines)
 {
-	HklEngineHkl *self;
+	HklEngineHkl *self = g_new(HklEngineHkl, 1);
 	static const HklParameter h = {
 		HKL_PARAMETER_DEFAULTS, .name = "h",
 		.description = "h coordinate of the diffracting plan",
@@ -861,8 +861,6 @@ HklEngine *hkl_engine_hkl_new(HklEngineList *engines)
 		.free=hkl_engine_hkl_free_real,
 	};
 
-	self = HKL_MALLOC(HklEngineHkl);
-
 	hkl_engine_init(&self->engine, &info, &operations, engines);
 
 	self->h = register_pseudo_axis(&self->engine, engines, &h);
