@@ -13,7 +13,7 @@
  * You should have received a copy of the GNU General Public License
  * along with the hkl library.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2003-2019, 2021 Synchrotron SOLEIL
+ * Copyright (C) 2003-2019, 2021, 2022 Synchrotron SOLEIL
  *                         L'Orme des Merisiers Saint-Aubin
  *                         BP 48 91192 GIF-sur-YVETTE CEDEX
  *
@@ -189,31 +189,35 @@ static inline int hkl_mode_set_real(UNUSED HklMode *self,
 }
 
 
+static inline int hkl_mode_init(HklMode *self,
+				const HklModeInfo *info,
+				const HklModeOperations *ops,
+				int initialized) HKL_ARG_NONNULL(1, 2, 3) HKL_WARN_UNUSED_RESULT;
 static inline int hkl_mode_init(HklMode *self,
 				const HklModeInfo *info,
 				const HklModeOperations *ops,
 				int initialized)
 {
 	const HklParameter *parameter;
-
-	/* ensure part */
-	if (!self)
-		return FALSE;
+        HklParameter *p;
 
 	self->info = info;
 	self->ops = ops;
 
 	/* parameters */
-	darray_init(self->parameters);
+	darray_init(self->parameters) ;
 	darray_init(self->parameters_names);
 	darray_foreach(parameter, self->info->parameters){
-		darray_append(self->parameters, hkl_parameter_new_copy(parameter));
+                if(NULL == (p = hkl_parameter_new_copy(parameter)))
+                        break;
+
+		darray_append(self->parameters, p);
 		darray_append(self->parameters_names, parameter->name);
 	}
 
 	self->initialized = initialized;
 
-	return TRUE;
+        return TRUE;
 }
 
 
@@ -221,9 +225,7 @@ static inline HklMode *hkl_mode_new(const HklModeInfo *info,
 				    const HklModeOperations *op,
 				    int initialized)
 {
-	HklMode *self = NULL;
-
-	self = HKL_MALLOC(HklMode);
+	HklMode *self = g_new(HklMode, 1);
 
 	hkl_mode_init(self, info, op, initialized);
 
@@ -391,19 +393,19 @@ static inline void hkl_engine_init(HklEngine *self,
 {
 	self->info = info;
 	self->ops = ops;
-	darray_init(self->modes);
-	darray_init(self->pseudo_axes);
-	darray_init(self->pseudo_axis_names);
-	darray_init(self->mode_names);
 	self->geometry = NULL;
 	self->detector = NULL;
 	self->sample = NULL;
 	self->engines = engines;
+        darray_init(self->axes);
+	darray_init(self->pseudo_axes);
+	darray_init(self->pseudo_axis_names);
+	darray_init(self->modes);
+	darray_init(self->mode_names);
 
 	darray_append(*engines, self);
 }
 
-
 static inline HklParameter *register_mode_parameter(HklMode *mode, unsigned int index)
 {
 	return darray_item(mode->parameters, index);
@@ -440,8 +442,8 @@ out:
  *
  * add an HklMode to the self HklEngine
  **/
-static inline void hkl_engine_add_mode(HklEngine *self,
-				       HklMode *mode)
+static inline void hkl_engine_add_mode(HklEngine *self, HklMode *mode) HKL_ARG_NONNULL(1, 2);
+static inline void hkl_engine_add_mode(HklEngine *self, HklMode *mode)
 {
 	darray_append(self->modes, mode);
 	darray_append(self->mode_names, mode->info->name);
@@ -710,10 +712,8 @@ static inline int hkl_engine_list_post_engine_set_real(UNUSED HklEngineList *sel
 static inline HklEngineList *hkl_engine_list_new_with_info(const HklEngineListInfo *info,
 							   const HklEngineListOperations *ops)
 {
-	HklEngineList *self = NULL;
 	const HklParameter **parameter;
-
-	self = HKL_MALLOC(HklEngineList);
+	HklEngineList *self = g_new(HklEngineList, 1);
 
 	/* This code needs _darray to be at start of HklEngineList */
 	BUILD_ASSERT(offsetof(HklEngineList, item) == 0);
@@ -764,7 +764,7 @@ static inline HklEngineList *hkl_engine_list_new(void)
  *
  * Returns: (transfer none): NULL all the time the structure is non-copyable
  **/
-static inline const HklEngineList *hkl_engine_list_new_copy(UNUSED const HklEngineList *self)
+static inline HklEngineList *hkl_engine_list_new_copy(UNUSED const HklEngineList *self)
 {
 	return NULL;
 }
